==> react-molecule-button-group-2.12.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "children", "fullWidth", "size", "design", "negative", "groupPositions", "onClick", "spaced", "isVertical"];
import { Children } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { atomButtonDesigns, atomButtonSizes } from '@s-ui/react-atom-button';
import Injector from '@s-ui/react-primitive-injector';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { SPACED } from './config.js';
import { BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var getGroupPosition = function getGroupPosition(_ref) {
  var groupPositions = _ref.groupPositions,
    numChildren = _ref.numChildren;
  return function (index) {
    if (index === 0) return groupPositions.FIRST;
    if (index === numChildren - 1) return groupPositions.LAST;
    return groupPositions.MIDDLE;
  };
};
var MoleculeButtonGroup = function MoleculeButtonGroup(_ref2) {
  var _ref2$as = _ref2.as,
    as = _ref2$as === void 0 ? 'div' : _ref2$as,
    children = _ref2.children,
    fullWidth = _ref2.fullWidth,
    size = _ref2.size,
    design = _ref2.design,
    negative = _ref2.negative,
    groupPositions = _ref2.groupPositions,
    onClick = _ref2.onClick,
    spaced = _ref2.spaced,
    isVertical = _ref2.isVertical,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var numChildren = children.length;
  var getGroupPositionByIndex = getGroupPosition({
    groupPositions: groupPositions,
    numChildren: numChildren
  });
  var CLASS_SPACED_MEDIUM = BASE_CLASS + "--spaced-" + SPACED.MEDIUM;
  var CLASS_SPACED_LARGE = BASE_CLASS + "--spaced-" + SPACED.LARGE;
  var getClassSpaced = function getClassSpaced(_ref3) {
    var spaced = _ref3.spaced;
    if (spaced === SPACED.MEDIUM) {
      return CLASS_SPACED_MEDIUM;
    }
    if (spaced === SPACED.LARGE) {
      return CLASS_SPACED_LARGE;
    }
    return CLASS_SPACED_MEDIUM;
  };
  var CLASS_SPACED = getClassSpaced({
    spaced: spaced
  });
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    var groupPosition = getGroupPositionByIndex(index);
    return /*#__PURE__*/_jsx(Injector, _extends({}, props, {
      negative: negative,
      size: size,
      design: design,
      groupPosition: groupPosition,
      fullWidth: fullWidth,
      spaced: spaced,
      onClick: onClick,
      children: child
    }));
  });
  return /*#__PURE__*/_jsx(Poly, {
    className: cx(BASE_CLASS, fullWidth && BASE_CLASS + "--fullWidth", spaced && CLASS_SPACED, isVertical && BASE_CLASS + "--vertical"),
    children: extendedChildren
  });
};
MoleculeButtonGroup.displayName = 'MoleculeButtonGroup';
MoleculeButtonGroup.defaultProps = {
  groupPositions: {
    FIRST: 'first',
    MIDDLE: 'middle',
    LAST: 'last'
  }
};
export default MoleculeButtonGroup;
export { atomButtonDesigns as moleculeButtonGroupDesigns, atomButtonSizes as moleculeButtonGroupSizes, SPACED as moleculeButtonGroupSpaced };

==> react-molecule-button-group-2.13.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "children", "fullWidth", "size", "design", "negative", "groupPositions", "onClick", "spaced", "isVertical"];
import { Children } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { atomButtonDesigns, atomButtonSizes } from '@s-ui/react-atom-button';
import Injector from '@s-ui/react-primitive-injector';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { SPACED } from './config.js';
import { BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var getGroupPosition = function getGroupPosition(_ref) {
  var groupPositions = _ref.groupPositions,
    numChildren = _ref.numChildren,
    spaced = _ref.spaced;
  return function (index) {
    if (spaced) {
      return groupPositions.UNSET;
    } else {
      if (index === 0) return groupPositions.FIRST;
      if (index === numChildren - 1) return groupPositions.LAST;
      return groupPositions.MIDDLE;
    }
  };
};
var MoleculeButtonGroup = function MoleculeButtonGroup(_ref2) {
  var _ref2$as = _ref2.as,
    as = _ref2$as === void 0 ? 'div' : _ref2$as,
    children = _ref2.children,
    fullWidth = _ref2.fullWidth,
    size = _ref2.size,
    design = _ref2.design,
    negative = _ref2.negative,
    _ref2$groupPositions = _ref2.groupPositions,
    groupPositions = _ref2$groupPositions === void 0 ? {
      FIRST: 'first',
      MIDDLE: 'middle',
      LAST: 'last',
      UNSET: 'unset'
    } : _ref2$groupPositions,
    onClick = _ref2.onClick,
    spaced = _ref2.spaced,
    isVertical = _ref2.isVertical,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var numChildren = children.length;
  var getGroupPositionByIndex = getGroupPosition({
    spaced: spaced,
    groupPositions: groupPositions,
    numChildren: numChildren
  });
  var CLASS_SPACED_MEDIUM = BASE_CLASS + "--spaced-" + SPACED.MEDIUM;
  var CLASS_SPACED_LARGE = BASE_CLASS + "--spaced-" + SPACED.LARGE;
  var getClassSpaced = function getClassSpaced(_ref3) {
    var spaced = _ref3.spaced;
    if (spaced === SPACED.MEDIUM) {
      return CLASS_SPACED_MEDIUM;
    }
    if (spaced === SPACED.LARGE) {
      return CLASS_SPACED_LARGE;
    }
    return CLASS_SPACED_MEDIUM;
  };
  var CLASS_SPACED = getClassSpaced({
    spaced: spaced
  });
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    var groupPosition = getGroupPositionByIndex(index);
    return /*#__PURE__*/_jsx(Injector, _extends({}, props, {
      negative: negative,
      size: size,
      design: design,
      groupPosition: groupPosition,
      fullWidth: fullWidth,
      spaced: spaced,
      onClick: onClick,
      children: child
    }));
  });
  return /*#__PURE__*/_jsx(Poly, {
    className: cx(BASE_CLASS, fullWidth && BASE_CLASS + "--fullWidth", spaced && CLASS_SPACED, isVertical && BASE_CLASS + "--vertical"),
    children: extendedChildren
  });
};
MoleculeButtonGroup.displayName = 'MoleculeButtonGroup';
export default MoleculeButtonGroup;
export { atomButtonDesigns as moleculeButtonGroupDesigns, atomButtonSizes as moleculeButtonGroupSizes, SPACED as moleculeButtonGroupSpaced };
